#!/bin/bash

# Building a Docker image in which to execute tests
# will require a copy of the local Capo properties
# file, which can be found at /home/casa/capo
# on boxes that can see /home, but which on boxes
# that can't is likely to be at ~/home/.capo for
# any given user. Find local.properties and
# copy it to our test directory. Dockerfiles
# do not support conditional logic; hence this script.

# Execute script from apps/executables/cli/datafetcher/
FILENAME=local.properties
CONTAINER_NAME=$1;shift
if [ -z ${CONTAINER_NAME} ]
then
  echo 'Usage: $0 <container_name>'
  exit 1
fi

# conda will need the environment.yml
export ENV_YML=environment.yml
export YML_DIR=../../../../
cp $YML_DIR${ENV_YML} ${ENV_YML}

# The preferred version of Capo .properties files is always
# the one at /home/casa/capo, -if- this is visible
# (i.e., NRAO internal system). If not (i.e., developer laptop),
# get the one in the user's .capo directory
if [ -e /home/casa/capo/${FILENAME} ]
then
    SOURCE=/home/casa/capo/${FILENAME}
elif [ -e ~/.capo/${FILENAME} ]
then
    SOURCE=~/.capo/${FILENAME}
else
  echo '${FILENAME} not found!'
  exit 1
fi

pwd
NEW_FILE=./test/${FILENAME}
cp ${SOURCE} ${NEW_FILE}

# remove extended attributes, which would cause Capo to balk
/usr/bin/xattr -c ${NEW_FILE}

# for quicker build, re-use cached intermediate containers
docker build . -f test/Dockerfile -t ${CONTAINER_NAME}
# -don't- use cached intermediate containers
#docker build . -f test/Dockerfile --no-cache -t ${CONTAINER_NAME}
# don't use -anything- cached, including the FROM image
# docker build . -f test/Dockerfile --no-cache -t ${CONTAINER_NAME} --pull

# now get rid of the properties file; containing sensitive info, it must NOT be saved or committed
rm -f ${NEW_FILE}
# get rid of the .yml, too
rm -f ${ENV_YML}

# to run the image: docker run ${CONTAINER_NAME}[:latest]
